// IFTTT/Adafruit IO/NeoPixel strio/bookend LED display by Margarita Zulueta and code help from Becky Stern
// This program contains bits and pieces of various library sample codes:
/*************************************************** 
  Adafruit LED 7-Segment backpacks 
  ----> http://www.adafruit.com/products/881
  ----> http://www.adafruit.com/products/880
  ----> http://www.adafruit.com/products/879
  ----> http://www.adafruit.com/products/878

  These displays use I2C to communicate, 2 pins are required to 
  interface. There are multiple selectable I2C addresses. For backpacks
  with 2 Address Select pins: 0x70, 0x71, 0x72 or 0x73. For backpacks
  with 3 Address Select pins: 0x70 thru 0x77

  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!

  I2C LED Backpack Example written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution
  
// Adafruit IO Multiple Feed Example written by Todd Treece for Adafruit Industries
// Smart Toilet Light with ESP8266 written by Tony DiCola for Adafruit Industries
// Licenses: MIT (https://opensource.org/licenses/MIT)
 ****************************************************/

#include <Wire.h> // Enable this line if using Arduino Uno, Mega, etc.
#include <Adafruit_GFX.h>
#include "Adafruit_LEDBackpack.h" 
#include "Adafruit_NeoPixel.h"

#include <ESP8266WiFi.h>
#include <AdafruitIO.h>
#include <Adafruit_MQTT.h>

// Adafruit IO Subscription Example
//
// Adafruit invests time and resources providing this open source code.
// Please support Adafruit and open source hardware by purchasing
// products from Adafruit!
//
// Written by Todd Treece for Adafruit Industries
// Copyright (c) 2016 Adafruit Industries
// Licensed under the MIT license.
//
// All text above must be included in any redistribution.

// edit the config.h tab and enter your Adafruit IO credentials
// and any additional configuration needed for WiFi, cellular,
// or ethernet clients.
#include "config.h"

// Configuration you can optionally change (but probably want to keep the same):
 #define PIXEL_PIN       2                      // Pin connected to the NeoPixel data input.
 #define PIXEL_COUNT     12                      // Number of NeoPixels.
 #define PIXEL_TYPE      NEO_GRBW + NEO_KHZ800   // Type of the NeoPixels (see strandtest example).

// Generally, you should use "unsigned long" for variables that hold time
// The value will quickly become too large for an int to store
unsigned long previousMillis = 0;        // will store last time LED was updated
const long interval = 60000;           // interval at which to count (milliseconds)
int minutes = 0;

// before running this code, create feeds on Adafruit IO that match these names:
AdafruitIO_Feed *gcalendar = io.feed("gcalendar"); // set up the 'google-calendar-events' feed

Adafruit_AlphaNum4 matrix = Adafruit_AlphaNum4();  // create segment display object

Adafruit_NeoPixel pixels = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, PIXEL_TYPE); // create NeoPixels object

void setup() {
  
  matrix.begin(0x70); // initialize matrix display
  
  // start the serial connection
  Serial.begin(115200);
  
  // Initialize NeoPixels and turn them off.
   pixels.begin();
   lightPixels(pixels.Color(0, 0, 0, 0));

  Serial.print("Connecting to Adafruit IO");

  // connect to io.adafruit.com
  io.connect();

  // set up a message handler for the count feed.
  // the handleMessage function (defined below)
  // will be called whenever a message is
  // received from adafruit io.
  gcalendar->onMessage(handleStart);

  // wait for a connection
  while(io.status() < AIO_CONNECTED) {
    Serial.print(".");
    delay(500);
  }

  // we are connected
  Serial.println();
  Serial.println(io.statusText());

}
char displaybuffer[4] = {' ', ' ', ' ', ' '};

void loop() {
  
  // io.run(); is required for all sketches.
  // it should always be present at the top of your loop
  // function. it keeps the client connected to
  // io.adafruit.com, and processes any incoming data.
  io.run();

  // check to see if it's time to count; that is, if the difference
  // between the current time and last time you counted is bigger than
  // the interval at which you want to count.
  unsigned long currentMillis = millis();

  if (currentMillis - previousMillis >= interval) {
    // save the last time you counted
    previousMillis = currentMillis;
    minutes--; // decrease minutes by 1
    itoa(minutes, displaybuffer, 10); //convert the integer into a char array
  }
  // set every digit to the buffer
  matrix.writeDigitAscii(0, displaybuffer[0]);
  matrix.writeDigitAscii(1, displaybuffer[1]);
  matrix.writeDigitAscii(2, displaybuffer[2]);
  matrix.writeDigitAscii(3, displaybuffer[3]);
  matrix.writeDisplay();          // display changes
    
  // if the meeting will begin in 45 minutes, tell the the pixels to be white
  if (minutes==45){
    Serial.println("41");
    lightPixels(pixels.Color(0, 0, 0, 255));
  }
  
  // if the meeting will begin in 30 minutes, tell the the pixels to be white
  if (minutes==30){
    Serial.println("30");
    lightPixels(pixels.Color(0, 0, 0, 255));
  }
    
  // if the meeting will begin in 15 minutes, tell the the pixels to be white
  if (minutes==15){
    Serial.println("15");
    lightPixels(pixels.Color(0, 0, 0, 255));
  }
      
  // if the meeting will begin now, tell the the pixels to be white
  if (minutes==0){
    Serial.println("0");
    lightPixels(pixels.Color(0, 0, 0, 255));
  }
  delay(500);                     // wait half a second
}

// this function is called whenever a feed message
// is received from Adafruit IO. it was attached to
// the feed in the setup() function above.
void handleStart(AdafruitIO_Data *data) {

  Serial.print("received <- ");
  Serial.println(data->value());  // print the minute data to the serial monitor
  
  minutes = data->toInt(); // store the incoming minute data as an integer
  itoa(minutes, displaybuffer, 10); //convert the integer into a char array

}

// Function to set all the NeoPixels to the specified color.
 void lightPixels(uint32_t color) {
  for (int i=0; i<PIXEL_COUNT; i++) {
    pixels.setPixelColor(i, color);
  }
   pixels.show();
   delay (50);
}
